@@ -12,9 +12,9 @@ import os
 
 import pytest
 
-from ovirt_imageio import config
 from ovirt_imageio import client
-from ovirt_imageio import server
+from ovirt_imageio._internal import config
+from ovirt_imageio._internal import server
 
 from . import testutil
 
